==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_zh.js <==

lang['incoming_call']      = '來電中';
lang['connecting_server']  = '正與伺服器連線中，嘗試次數 ';

lang['from_queue']         = "從接聽群組Queue:";
lang['number']             = "電話號碼:";
lang['name']               = "名字:";

lang['dial']               = '呼叫';
lang['transfer_vmail']     = '轉到語音信箱';
lang['attendant_transfer'] = '轉接';
lang['transfer_external']  = '转移到手机';
lang['spy']                = '監聽';
lang['whisper']            = '監聽並傳話給一方';
lang['pickup']             = "代接";
lang['hangup']             = '掛斷';
lang['filter']             = '按鈕搜尋';

lang['enter_sec_code']     = '登入資訊';
lang['exten']              = '分機號碼:';
lang['password']           = '密碼:';

lang['confirm_hangup']     = '確認掛斷通話';
lang['areyousure']         = '您確定嗎?';
lang['yes']                = '確認';
lang['no']                 = '取消';

lang['paused']             = '暫停中';
lang['set_information']    = '設定資訊';
lang['member_of']          = '的成員';
lang['not_available']      = '系統目前非使用中';
lang['not_connect']        = '無法連線至伺服器';
lang['one_moment']         = '請稍待片刻';
lang['no_results']         = '找不到和您的查詢相符的資料';

lang['toggle_lock']        = '會議室關閉/開啟';
lang['toggle_muteall']     = '靜音全部/取消靜音';
lang['available']          = '線上';
lang['phonebook']          = '電話簿';
lang['toggle_mute']        = '靜音切換';
lang['kick']               = '趕走使用者';
lang['record']             = '錄音';
lang['presence_noti']      = '出席通知';

lang['queues']             = '接聽群組 Queues';
lang['extensions']         = '分機 Extensions';
lang['trunks']             = '中繼 Trunks';
lang['conferences']        = '會議室 Conferences';
lang['other']              = '其他';
lang['enter_state']        = '輸入狀態';
lang['parkingslots']       = '駐留空位Park Slots';
lang['ringgroups']         = '通话组';

lang['enter_reg_code']     = '輸入註冊碼:';
lang['reg_code']           = '註冊碼:';
lang['reg_name']           = '註冊姓名:';

lang['remove_member']      = '移除成員';
lang['remove_member_from'] = '移除成員從 ';
lang['pause_member']       = '暫停成員';
lang['unpause_member']     = '解除暫停成員';
lang['add_member']         = '加入成員';
lang['pickup_call']        = '接聽來電';
lang['email_user']         = '寄電子郵件';
lang['send_sms']           = '发送短信';
lang['message']            = '消息:';
lang['sending']            = '发送';
lang['noResponse']         = '无响应';

lang['chat']               = '交谈';
lang['notlogged']          = '用户未登录注意节约';
lang['me']                 = '我';
lang['clearchat']          = '清除聊天窗口';
lang['note']               = '笔记';
lang['toggle_sound']       = '切换声音';
lang['says']               = '说：';

lang['agents']             = '代理商: %d';
lang['calls']              = '呼叫等待: %d';
lang['call_connected']     = '交谈';
lang['changeDisplayType']  = '更改显示器类型';

lang['voicemail']          = '语音信箱';
lang['vmail_new']          = '未讀';
lang['vmail_old']          = '已讀';
lang['vmail_work']         = '工作';
lang['vmail_family']       = '家庭';
lang['vmail_friends']      = '朋友';
lang['vmail_number']       = '数';
lang['vmail_date']         = '日期';
lang['vmail_callerid']     = '来电显示';
lang['vmail_duration']     = '为期';

lang['preferences']        = '喜好';
lang['summary']            = '摘要';
lang['detailed']           = '详细';

lang['inactive_line']      = '線路%d 非使用中';
lang['inuse']              = '線路%d  通話中';
lang['vmail_count']        = '未讀%d, 已讀 %d';
lang['logout']             = '走'

lang['NOTONLINE']          = '用户离线';
lang['NOWONLINE']          = '用户现在在线';

lang['prefSounds']         = '声音';
lang['prefDisplay']        = '显示';

lang['labelSoundChat']     = '聊天的声音';
lang['labelSoundQueue']    = '队列的声音';
lang['labelSoundRing']     = '手机会发出';

lang['labelDisplayQueue']          = '默认队列查看:';
lang['labelDisplayDynamicLine']    = '动态行显示:';
lang['labelDisplayNotifyDuration'] = '通知期限:';
lang['labelDisplayLanguage']       = '语言:';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
        "周日","周一","周二","周三","周四","周五","周六",
        "周日","周一","周二","周三","周四","周五","周六"
	],
	monthNames: [
        "一月","二月","三月","四月","五月","六月","七月", "八月","九月","十月","十一月","十二月",
        "一月","二月","三月","四月","五月","六月","七月", "八月","九月","十月","十一月","十二月"
	]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_zh.js <==

lang['incoming_call']      = '來電中';
lang['connecting_server']  = '正與伺服器連線中，嘗試次數 ';

lang['from_queue']         = "從接聽群組Queue:";
lang['number']             = "電話號碼:";
lang['name']               = "名字:";

lang['dial']               = '呼叫';
lang['transfer_vmail']     = '轉到語音信箱';
lang['attendant_transfer'] = '轉接';
lang['blind_transfer']     = '盲转';
lang['transfer_external']  = '转移到手机';
lang['spy']                = '監聽';
lang['whisper']            = '監聽並傳話給一方';
lang['pickup']             = "代接";
lang['hangup']             = '掛斷';
lang['filter']             = '按鈕搜尋';

lang['enter_sec_code']     = '登入資訊';
lang['exten']              = '分機號碼:';
lang['password']           = '密碼:';

lang['confirm_hangup']     = '確認掛斷通話';
lang['areyousure']         = '您確定嗎?';
lang['yes']                = '確認';
lang['no']                 = '取消';
lang['cancel']             = '取消';
lang['accept']             = '接受';

lang['paused']             = '暫停中';
lang['set_information']    = '設定資訊';
lang['set_penalty']        = '刑罚';
lang['member_of']          = '的成員';
lang['not_available']      = '系統目前非使用中';
lang['not_connect']        = '無法連線至伺服器';
lang['one_moment']         = '請稍待片刻';
lang['no_results']         = '找不到和您的查詢相符的資料';

lang['toggle_lock']        = '會議室關閉/開啟';
lang['toggle_muteall']     = '靜音全部/取消靜音';
lang['available']          = '線上';
lang['phonebook']          = '電話簿';
lang['toggle_mute']        = '靜音切換';
lang['kick']               = '趕走使用者';
lang['record']             = '錄音';
lang['presence_noti']      = '出席通知';

lang['queues']             = '接聽群組 Queues';
lang['extensions']         = '分機 Extensions';
lang['trunks']             = '中繼 Trunks';
lang['conferences']        = '會議室 Conferences';
lang['other']              = '其他';
lang['enter_state']        = '輸入狀態';
lang['parkingslots']       = '駐留空位Park Slots';
lang['ringgroups']         = '通话组';

lang['enter_reg_code']     = '輸入註冊碼:';
lang['reg_code']           = '註冊碼:';
lang['reg_name']           = '註冊姓名:';

lang['remove_member']      = '移除成員';
lang['remove_member_from'] = '移除成員從 ';
lang['pause_member']       = '暫停成員';
lang['unpause_member']     = '解除暫停成員';
lang['add_member']         = '加入成員';
lang['pickup_call']        = '接聽來電';
lang['email_user']         = '寄電子郵件';
lang['send_sms']           = '发送短信';
lang['message']            = '消息:';
lang['sending']            = '发送';
lang['noResponse']         = '无响应';
lang['calls_taken']        = '呼吁采取:';
lang['penalty']            = '刑罚:';

lang['chat']               = '交谈';
lang['notlogged']          = '用户未登录注意节约';
lang['me']                 = '我';
lang['clearchat']          = '清除聊天窗口';
lang['note']               = '笔记';
lang['toggle_sound']       = '切换声音';
lang['says']               = '说：';

lang['agents']             = '代理商: %d';
lang['calls']              = '呼叫等待: %d';
lang['call_connected']     = '交谈';
lang['changeDisplayType']  = '更改显示器类型';

lang['voicemail']          = '语音信箱';
lang['vmail_new']          = '未讀';
lang['vmail_old']          = '已讀';
lang['vmail_work']         = '工作';
lang['vmail_family']       = '家庭';
lang['vmail_friends']      = '朋友';
lang['vmail_number']       = '数';
lang['vmail_date']         = '日期';
lang['vmail_callerid']     = '来电显示';
lang['vmail_duration']     = '为期';
lang['play']               = '玩';
lang['download']           = '下载';

lang['preferences']        = '喜好';
lang['summary']            = '摘要';
lang['detailed']           = '详细';

lang['inactive_line']      = '線路%d 非使用中';
lang['inuse']              = '線路%d  通話中';
lang['vmail_count']        = '未讀%d, 已讀 %d';
lang['logout']             = '走'

lang['NOTONLINE']          = '用户离线';
lang['NOWONLINE']          = '用户现在在线';

lang['prefSounds']         = '声音';
lang['prefDisplay']        = '显示';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = '电话';

lang['labelSoundChat']     = '聊天的声音';
lang['labelSoundQueue']    = '队列的声音';
lang['labelSoundRing']     = '手机会发出';

lang['labelDisplayQueue']          = '默认队列查看';
lang['labelDisplayDynamicLine']    = '动态行显示';
lang['labelDisplayNotifyDuration'] = '通知期限';
lang['labelDisplayLanguage']       = '语言';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = '自动应答';

lang['close']                      = '关闭';
lang['recordings']                 = '录音';
lang['cdrrecords']                 = '通话记录';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
        "周日","周一","周二","周三","周四","周五","周六",
        "周日","周一","周二","周三","周四","周五","周六"
	],
	monthNames: [
        "一月","二月","三月","四月","五月","六月","七月", "八月","九月","十月","十一月","十二月",
        "一月","二月","三月","四月","五月","六月","七月", "八月","九月","十月","十一月","十二月"
	]
};
